@@ -272,21 +272,21 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 	
 	if (g_strcmp0(language_string, languages[n].str_long) != 0)
 	{
-		//g_debug("search on!\n");
+		g_debug("search on!\n");
 		
 		for (n = 0; n < 52; n++)
 		{
 			if (g_strcmp0(language_string, languages[n].str_long) == 0)
 			{
-				//g_debug("%s = %s\n", language_string, languages[n].str_long);
+				g_debug("%s = %s\n", language_string, languages[n].str_long);
 				break;
 			}
 		}
 	}
-	/*else
+	else
 	{
 		g_debug("search off!\n");
-	}*/
+	}
 	
 	if ((gint)data == 1)
 	{
@@ -295,18 +295,10 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 		index_src_lang = n;
 		hildon_button_set_image(HILDON_BUTTON(button_src_lang), gtk_image_new_from_pixbuf(flags[n]));
 		gtk_widget_set_sensitive(button_say1, languages[n].espeak);
-		
-		if (n == 0)
-		{
-			gtk_widget_set_sensitive(button_swap, FALSE);
-		}
-		else
-		{
-			gtk_widget_set_sensitive(button_swap, TRUE);
-		}
 	}
 	else
 	{
+		//n++;
 		hildon_button_set_value(HILDON_BUTTON(button_tar_lang), languages[n].str_long);
 		settings_int_set("default", "tar_lang", n);
 		index_tar_lang = n;
@@ -314,6 +306,18 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 		gtk_widget_set_sensitive(button_say2, languages[n].espeak);
 	}
 	
+	if (index == 0)
+	{
+		gtk_widget_set_sensitive(button_swap, FALSE);
+		//gtk_widget_set_sensitive(button_say1, FALSE);
+	}
+	else
+	{
+		gtk_widget_set_sensitive(button_swap, TRUE);
+		//gtk_widget_set_sensitive(button_say1, TRUE);
+	}
+	
+ 	//g_print("select item: %s = %s\n", languages[index_src_lang].str_short, languages[index_src_lang].str_long);
  	gtk_widget_destroy(dialog);
 }
 
@@ -344,7 +348,6 @@ void show_about(GtkWidget* widget, gpointer data)
 	
 	GtkWidget* text = hildon_text_view_new();
 	gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
-	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text), FALSE);
 	
 	GdkPixbuf* google_translate = gdk_pixbuf_new_from_file(DATAPREFIX"/google.png", NULL);
 	
@@ -398,7 +401,7 @@ void show_settings(GtkWidget* widget, gpointer data)
 	//gtk_window_set_title(GTK_WINDOW(settings_dialog), "Settings");
 	gtk_window_set_transient_for(GTK_WINDOW(settings_dialog), GTK_WINDOW(window));
 	
-	//GtkWidget* caption_speech = gtk_label_new("Speech Synthesizer");
+	GtkWidget* caption_speech = gtk_label_new("Speech Synthesizer");
 	
 	/*radio_male = hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
 	gtk_button_set_label(GTK_BUTTON(radio_male), "Male");
@@ -429,21 +432,18 @@ void show_settings(GtkWidget* widget, gpointer data)
 	gtk_scale_set_value_pos(GTK_SCALE(slider_speed), GTK_POS_RIGHT);
 	gtk_range_set_value(GTK_RANGE(slider_speed), (gdouble)settings_int_get("voice", "speed", 181));
 	
-	slider_wordgap = gtk_hscale_new_with_range(0.0, 20.0, 1.0);
+	slider_wordgap = gtk_hscale_new_with_range(5.0, 100.0, 1.0);
 	gtk_scale_set_value_pos(GTK_SCALE(slider_wordgap), GTK_POS_RIGHT);
 	gtk_range_set_value(GTK_RANGE(slider_wordgap), (gdouble)settings_int_get("voice", "wordgap", 5));
 	
 	GtkWidget* vbox = gtk_vbox_new(TRUE, 0);
-	//gtk_box_pack_start(GTK_BOX(vbox), caption_speech, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), caption_speech, FALSE, TRUE, 0);
 	//gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Gender\t\t", gender_hbox,    NULL, 0),  FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Pitch\t\t",  slider_pitch,   NULL, 0),  FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Speed\t\t",  slider_speed,   NULL, 0),  FALSE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Word gap\t", slider_wordgap, NULL, 0),  FALSE, TRUE, 0);
 	
-	GtkWidget* frame_speech = gtk_frame_new("Speech Synthesizer");
-	gtk_container_add(GTK_CONTAINER(frame_speech), vbox);
-	
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(settings_dialog)->vbox), frame_speech);
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(settings_dialog)->vbox), vbox);
 	
 	g_signal_connect_swapped(settings_dialog, "response", G_CALLBACK(settings_response), NULL);
 	
